@@ -41,7 +41,7 @@ class Generation:
         else:
             assert path is not None, "you must provide `file_name` or `path` args"
         with open(path, 'a') as fp:
-            self._yaml_obj["meta_info"].dump({"meta", meta_info}, fp)
+            self._yaml_obj["meta_info"].dump({"meta": meta_info}, fp)
             fp.writelines([os.linesep] * self.LINESEP_NUM)
 
     def write_dsdl_version(self, file_name=None, path=None):
